==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Input/cue/translations/cue_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>ЦУЕ прикључак</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>ЦУЕ фајлови</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="98"/>
        <source>About CUE Audio Plugin</source>
        <translation>О ЦУЕ прикључку</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="99"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Кумп ЦУЕ прикључак</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="100"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Поставке ЦУЕ прикључка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Опште</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Учитај неисправне ЦУЕ листове ако је могуће</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>ЦУЕ кодирање</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Аутоматско откривање кодирања</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Језик:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Подразумијевано:</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/cue/translations/cue_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="39"/>
        <source>CUE Plugin</source>
        <translation>ЦУЕ прикључак</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="42"/>
        <source>CUE Files</source>
        <translation>ЦУЕ фајлови</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="91"/>
        <source>About CUE Audio Plugin</source>
        <translation>О ЦУЕ прикључку</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="92"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Кумп ЦУЕ прикључак</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="93"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Поставке ЦУЕ прикључка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Опште</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Учитај неисправне ЦУЕ листове ако је могуће</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>ЦУЕ кодирање</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Аутоматско откривање кодирања</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Језик:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Подразумијевано:</translation>
    </message>
</context>
</TS>
